@@ -38,8 +38,31 @@ def annotation_suggester(sheet, selection, annotation_blocks_array):
             already_has_var=True
 
     (x1, y1), (x2, y2) = (selection["x1"]-1, selection["y1"]-1), (selection["x2"]-1, selection["y2"]-1)
-    first_cell=sheet[y1, x1]
-    is_country, is_numeric, is_date=get_types(first_cell)
+    totals = [0,0,0]
+    cells=[]
+    cells.append(sheet[y1, x1])
+    cells.append(sheet[y2, x2])
+    if y1!=y2:
+        cells.append(sheet[floor((y2-y1)/2), x1])
+    if x1!=x2:
+        cells.append(sheet[y1, floor((x2-x1)/2)])
+    for cell in cells:
+        cell=str(cell).strip()
+        if not cell:
+            continue
+        result_tuple = get_types(cell)
+        for i, b_result in enumerate(result_tuple):
+            if b_result:
+                totals[i]+=1
+    for i in range(len(totals)):
+        totals[i] = totals[i]/len(cells)
+        totals[i] = True if totals[i]>=0.5 else False
+    totals=tuple(totals)
+    is_country, is_numeric, is_date = totals
+
+
+
+
 
     children={}
     type=None
