@@ -1,6 +1,5 @@
 from copy import deepcopy
 from collections import defaultdict
-from t2wml.utils.debug_logging import basic_debug
 from t2wml.input_processing.region import YamlRegion
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.parsing.t2wml_parsing import iter_on_n_for_code, T2WMLCode
@@ -78,7 +77,6 @@ class Node:
     def errors(self):
         return list(self._errors)
 
-    @basic_debug
     def validate(self):
         if t2wml_settings.no_wikification:
             return
@@ -246,7 +244,6 @@ class NodeForEval(Node):
                 self.__dict__.pop(key)
         return cell_indices
 
-    @basic_debug
     def validate(self):
         # if it isn't already defined outside
         t_var_qcol = self.context.get("t_var_qcol", None)
@@ -270,7 +267,6 @@ class EvaluatedStatement(Statement, NodeForEval):
     def node_class(self):
         return NodeForEval
 
-    @basic_debug
     def _validate(self):
         try:
             subject = self.subject
