@@ -1,4 +1,3 @@
-from t2wml.utils.debug_logging import basic_debug
 from t2wml.utils.t2wml_exceptions import ModifyingItemsIsForbiddenException
 from t2wml.utils.bindings import bindings
 from t2wml.spreadsheets.conversions import to_excel
@@ -48,15 +47,12 @@ class ReturnClass:
         return str(self.value)
 
     def __bool__(self):
-        try:
             if self.value is None: #unfindable items are False values
                 return False
             if len(str(self.value).strip())==0: #empty cells are False values
                 return False
             return True #for now everything else is True (may eventually need to add NaN or something...)
-        except Exception as e:
-            #print(e)
-            raise(e)
+
             
     def __repr__(self):
         return to_excel(self.col, self.row) + " : "+str(self.value)
@@ -92,7 +88,6 @@ class RangeClass:
 
 
 class Item(ReturnClass):
-    @basic_debug
     def __init__(self, col, row, context):
         super().__init__(col, row)
         item_table = bindings.item_table
@@ -140,7 +135,6 @@ class ItemExpression:
 
 
 class Cell(ReturnClass):
-    @basic_debug
     def __init__(self, col, row):
         super().__init__(col, row)
         data_sheet = bindings.excel_sheet
